Pillow
======

Pillow is the friendly PIL fork by `Alex Clark and Contributors <https://github.com/python-pillow/Pillow/graphs/contributors>`_. PIL is the Python Imaging Library by Fredrik Lundh and Contributors.

.. image:: https://zenodo.org/badge/17549/python-pillow/Pillow.svg
   :target: https://zenodo.org/badge/latestdoi/17549/python-pillow/Pillow

.. image:: https://readthedocs.org/projects/pillow/badge/?version=latest
   :target: https://pillow.readthedocs.io/?badge=latest
   :alt: Documentation Status

.. image:: https://travis-ci.org/python-pillow/Pillow.svg?branch=master
   :target: https://travis-ci.org/python-pillow/Pillow
   :alt: Travis CI build status (Linux)

.. image:: https://travis-ci.org/python-pillow/pillow-wheels.svg?branch=latest
   :target: https://travis-ci.org/python-pillow/pillow-wheels
   :alt: Travis CI build status (macOS)

.. image:: https://img.shields.io/appveyor/ci/python-pillow/Pillow/master.svg?label=Windows%20build
   :target: https://ci.appveyor.com/project/python-pillow/Pillow
   :alt: AppVeyor CI build status (Windows)

.. image:: https://img.shields.io/pypi/v/pillow.svg
   :target: https://pypi.python.org/pypi/Pillow/
   :alt: Latest PyPI version

.. image:: https://coveralls.io/repos/python-pillow/Pillow/badge.svg?branch=master
   :target: https://coveralls.io/github/python-pillow/Pillow?branch=master
   :alt: Code coverage

.. toctree::
   :maxdepth: 2

   installation.rst
   handbook/index.rst
   reference/index.rst
   porting.rst
   about.rst
   releasenotes/index.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
